WorkflowFailure<TContext> class

Inheritance

Constructors

WorkflowFailure({required TContext context, required List<WorkflowStepEvent> history, required String failedStepId, required Object error, required StackTrace stackTrace, Map<String, Object> rollbackErrors = const {}})
const

Properties

context → TContext
finalinherited
error Object
final
failedStepId String
final
hashCode int
The hash code for this object.
no setterinherited
history List<WorkflowStepEvent>
finalinherited
rollbackErrors Map<String, Object>
Errors that occurred during the rollback (compensation) phase of completed steps.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited